#ifndef NT2_INCLUDE_FUNCTIONS_PREDECESSOR_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_PREDECESSOR_HPP_INCLUDED

#include <nt2/ieee/include/functions/predecessor.hpp>

#endif
